JSBSimProcessProperties

Struct JSBSimProcessProperties 

pub struct JSBSimProcessProperties {
    pub executable_name: String,
    pub root: PathBuf,
    pub aircraft: Option<String>,
    pub init_script: Option<String>,
    pub script: Option<String>,
    pub simulation_hz: u32,
    pub suspend_on_start: bool,
    pub realtime: bool,
    pub port: u16,
}
Configuration used when spawning a JSBSim process via JSBSim::new_with_process.

Construct with Default::default() for a sensible local testing configuration and override fields as necessary.

Fields

executable_name: String

The name of the JSBSim executable

root: PathBuf

The JSBSim root directory

aircraft: Option<String>

The aircraft to load on start

init_script: Option<String>

The initialization script for the aircraft to run on start

script: Option<String>

The script to run on start

simulation_hz: u32

Low simulation rates can lead to unstable behavior or FP exceptions in JSBSim

suspend_on_start: bool

Run the simulation in a suspended state on start

realtime: bool

Run the simulation in real time mode

port: u16

The port to connect to JSBSim on